# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: biointerface.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x62iointerface.proto\x12\x06\x61llego\x1a\x0c\x63ommon.proto\"!\n\x0cSpikesStdReq\x12\x11\n\tdsourceID\x18\x01 \x02(\t\"\x14\n\x12SpikesNewLoadReply\"<\n\x0fSpikesRenameReq\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x16\n\x0eisForceReplace\x18\x02 \x01(\x08\"\x13\n\x11SpikesGetIDsReply\"\xa3\x04\n\x0fSpikesSpecReply\x12\x16\n\x0e\x62iointerfaceID\x18\x01 \x02(\t\x12\x12\n\ndatasetUID\x18\x02 \x02(\t\x12\x10\n\x08\x63hecksum\x18\x03 \x02(\t\x12\x15\n\rprovenanceUID\x18\x04 \x03(\t\x12\x12\n\npersistDur\x18\x06 \x02(\x01\x12\x10\n\x08sampFreq\x18\x07 \x02(\x01\x12\x10\n\x08numSites\x18\x08 \x02(\x03\x12\x11\n\tsizeBytes\x18\t \x02(\x03\x12\x1d\n\x15\x65nabledSiteNtvChanIdx\x18\n \x03(\x05\x12\x11\n\ttimeRange\x18\x0b \x03(\x01\x12\x16\n\x0etimestampRange\x18\x0c \x03(\x03\x12\x15\n\rwallTimeStart\x18\r \x02(\t\x12$\n\x04site\x18\x0e \x03(\x0b\x32\x16.allego.SpikesSiteSpec\x12*\n\tsiteStats\x18\x11 \x01(\x0b\x32\x17.allego.SpikesSiteStats\x12\x31\n\tsensorExt\x18\x12 \x01(\x0b\x32\x1e.allego.SensorExtendedMetadata\x12(\n\x07project\x18\x13 \x01(\x0b\x32\x17.allego.ProjectMetadata\x12)\n\x07\x62ioType\x18\x14 \x02(\x0e\x32\x18.allego.BiointerfaceType\x12\x17\n\x0freqNumNeighbors\x18\x15 \x01(\x03\x12\x1c\n\x14neighborhoodRadiusUm\x18\x16 \x01(\x01\"\xc5\x04\n\x0eSpikesSiteSpec\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x05\x12,\n\x08neighbor\x18\x02 \x02(\x0b\x32\x1a.allego.NeighborDescriptor\x12\x11\n\tisEnabled\x18\x03 \x02(\x08\x12\x10\n\x08posProbe\x18\x04 \x03(\x01\x12\x11\n\tposTissue\x18\x05 \x03(\x01\x12\x11\n\tsizeBytes\x18\x06 \x02(\x03\x12\x10\n\x08sampFreq\x18\x07 \x02(\x01\x12\x15\n\rwallTimeStart\x18\x08 \x02(\t\x12\x11\n\ttimeRange\x18\t \x03(\x01\x12\x16\n\x0etimestampRange\x18\n \x03(\x03\x12\x16\n\x0espikeTimeRange\x18\x0b \x03(\x01\x12\x1b\n\x13spikeTimestampRange\x18\x0c \x03(\x03\x12\x1c\n\x14spikeTimeRangeMemory\x18\r \x03(\x01\x12!\n\x19spikeTimestampRangeMemory\x18\x0e \x03(\x03\x12\x1c\n\x14spikeCountSiteMemory\x18\x0f \x01(\x03\x12\x16\n\x0espikeCountSite\x18\x10 \x03(\x01\x12\x15\n\rspikeRateSite\x18\x11 \x03(\x01\x12\x14\n\x0cnoiseLevelSd\x18\x12 \x02(\x01\x12\x0f\n\x07snrSite\x18\x13 \x02(\x01\x12(\n\x06neuron\x18\x14 \x03(\x0b\x32\x18.allego.NeuronDescriptor\x12\x12\n\nnumNeurons\x18\x15 \x01(\x05\x12*\n\x07\x63ompLen\x18\x16 \x02(\x0b\x32\x19.allego.SpikeComponentLen\"!\n\x10SpikeLabelRecord\x12\r\n\x05label\x18\x01 \x03(\x05\"\x9a\x02\n\x0bSpikeMatrix\x12\x11\n\tnumSpikes\x18\x01 \x02(\x03\x12\x17\n\x0ftimestampsBytes\x18\x02 \x02(\x0c\x12\x0e\n\x06labels\x18\x03 \x03(\t\x12\x15\n\rwaveformBytes\x18\x04 \x01(\x0c\x12\x13\n\x0bwaveformLen\x18\x05 \x01(\x05\x12\x15\n\rfeaturesBytes\x18\x06 \x01(\x0c\x12\x13\n\x0b\x66\x65\x61turesLen\x18\x07 \x01(\x05\x12\x16\n\x0e\x66\x65\x61tures2Bytes\x18\x08 \x01(\x0c\x12\x14\n\x0c\x66\x65\x61tures2Len\x18\t \x01(\x05\x12\x13\n\x0bzscoreBytes\x18\n \x01(\x0c\x12\x11\n\tzscoreLen\x18\x0b \x01(\x05\x12\x0f\n\x07siteIdx\x18\x0c \x01(\x05\x12\x10\n\x08spikePos\x18\r \x03(\x05\"}\n\x0eSpikeMatrixSet\x12\x0b\n\x03uID\x18\x01 \x02(\t\x12\x0f\n\x07siteIdx\x18\x02 \x03(\x05\x12\x16\n\x0etimestampRange\x18\x03 \x03(\x03\x12\x10\n\x08sampFreq\x18\x04 \x02(\x01\x12#\n\x06spkMtx\x18\x05 \x03(\x0b\x32\x13.allego.SpikeMatrix\"\x93\x01\n\x14NeuronSpikeMatrixSet\x12\x0e\n\x06labels\x18\x01 \x03(\t\x12\x10\n\x08sampFreq\x18\x02 \x02(\x01\x12\x0f\n\x07siteIdx\x18\x03 \x03(\x05\x12#\n\x06spkMtx\x18\x04 \x03(\x0b\x32\x13.allego.SpikeMatrix\x12\x16\n\x0etimestampRange\x18\x05 \x03(\x03\x12\x0b\n\x03uID\x18\x06 \x02(\t\"\x94\x02\n\x1c\x42iointerfaceGetSpikesRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\'\n\x04mode\x18\x02 \x02(\x0e\x32\x19.allego.NeuronsSignalMode\x12\x12\n\nntvChanIdx\x18\x03 \x03(\x05\x12\x11\n\ttimeStart\x18\x04 \x02(\x01\x12\x10\n\x08timeStop\x18\x05 \x02(\x01\x12-\n\x0bspikeLabels\x18\x06 \x03(\x0b\x32\x18.allego.SpikeLabelRecord\x12\x1b\n\x13maxSpikesPerChannel\x18\x07 \x02(\x05\x12\x33\n\tspikeComp\x18\x08 \x03(\x0e\x32 .allego.SpikeDescriptorComponent\"\x99\x01\n\x1a\x42iointerfaceGetHistRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12%\n\x04mode\x18\x02 \x02(\x0e\x32\x17.allego.HistScalingMode\x12\x12\n\nntvChanIdx\x18\x03 \x03(\x05\x12-\n\x0bspikeLabels\x18\x04 \x03(\x0b\x32\x18.allego.SpikeLabelRecord\"\x90\x01\n%BiointerfaceGetSpikeTimestampsRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x12\n\nntvChanIdx\x18\x02 \x03(\x05\x12\x11\n\ttimeRange\x18\x03 \x03(\x01\x12-\n\x0bspikeLabels\x18\x06 \x03(\x0b\x32\x18.allego.SpikeLabelRecord\"\x8b\x01\n BiointerfaceSpikeTimestampsReply\x12<\n\x18spikeTimestampsByChannel\x18\x02 \x03(\x0b\x32\x1a.allego.SpikeTimestampData\x12\x11\n\ttimeRange\x18\x03 \x03(\x01\x12\x16\n\x0etimeStampRange\x18\x04 \x03(\x03\"S\n)BiointerfaceSeekEndSpikeTimestampsRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x13\n\x0b\x63omponentID\x18\x02 \x02(\t\"Y\n\x1d\x42iointerfaceGetNeuronsRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x12\n\nntvChanIdx\x18\x02 \x03(\x05\x12\x11\n\ttimeRange\x18\x03 \x03(\x01\"\xe4\x02\n\x1b\x42iointerfaceGetNeuronsReply\x12;\n\x04site\x18\x01 \x03(\x0b\x32-.allego.BiointerfaceGetNeuronsReply.SiteEntry\x1a\x36\n\x0eSpikeRateChunk\x12\x11\n\ttimeRange\x18\x01 \x03(\x01\x12\x11\n\tspikeRate\x18\x02 \x03(\x01\x1av\n\x07NeuronL\x12(\n\x06neuron\x18\x01 \x03(\x0b\x32\x18.allego.NeuronDescriptor\x12\x41\n\x05\x63hunk\x18\x02 \x01(\x0b\x32\x32.allego.BiointerfaceGetNeuronsReply.SpikeRateChunk\x1aX\n\tSiteEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.allego.BiointerfaceGetNeuronsReply.NeuronL:\x02\x38\x01\"\x87\x02\n\x0fSpikesSiteStats\x12\x17\n\x0fspikeCountStats\x18\t \x03(\x01\x12\x1e\n\x16labeledSpikeCountStats\x18\n \x03(\x01\x12 \n\x18unlabeledSpikeCountStats\x18\x0b \x03(\x01\x12\x16\n\x0espikeRateStats\x18\x0c \x03(\x01\x12\x1d\n\x15labeledSpikeRateStats\x18\r \x03(\x01\x12\x1f\n\x17unlabeledSpikeRateStats\x18\x0e \x03(\x01\x12\x16\n\x0esiteNoiseStats\x18\x0f \x03(\x01\x12\x14\n\x0csiteSnrStats\x18\x10 \x03(\x01\x12\x13\n\x0bneuronStats\x18\x11 \x03(\x01\"f\n\x11SpikeComponentLen\x12\x10\n\x08waveform\x18\x01 \x02(\x05\x12\x0f\n\x07\x66\x65\x61ture\x18\x02 \x02(\x05\x12\x10\n\x08\x66\x65\x61ture2\x18\x03 \x02(\x05\x12\x0e\n\x06zscore\x18\x04 \x02(\x05\x12\x0c\n\x04nbrs\x18\x05 \x03(\x05\"\xa8\x01\n\x12NeighborDescriptor\x12\x0e\n\x06radius\x18\x01 \x02(\x01\x12\x12\n\nntvChanIdx\x18\x02 \x03(\x05\x12\x10\n\x08\x64istance\x18\x03 \x03(\x01\x12\x10\n\x08thetaDeg\x18\x04 \x03(\x01\x12\x0e\n\x06phiDeg\x18\x05 \x03(\x01\x12\x0b\n\x03num\x18\x06 \x02(\x05\x12\x14\n\x0cSiteCenterUm\x18\x07 \x03(\x01\x12\x17\n\x0fSiteCenterTcsUm\x18\x08 \x03(\x01\"\xf3\x01\n\x10NeuronDescriptor\x12\x10\n\x08neuronID\x18\x01 \x02(\t\x12\x16\n\x0esiteNtvChanIdx\x18\x02 \x02(\x05\x12\x12\n\nspikeLabel\x18\x03 \x02(\t\x12\x10\n\x08posProbe\x18\x04 \x03(\x01\x12\x11\n\tposTissue\x18\x05 \x03(\x01\x12\x12\n\nspikeCount\x18\x06 \x02(\x03\x12\x11\n\tspikeRate\x18\x07 \x02(\x01\x12\x16\n\x0emeanAbsPeakWfm\x18\x08 \x01(\x01\x12\x0b\n\x03snr\x18\t \x01(\x01\x12\x30\n\x08metaData\x18\n \x01(\x0b\x32\x1e.allego.NeuronExtendedMetadata\"\x86\x01\n\x16NeuronExtendedMetadata\x12\x18\n\x10neuronCatalogUID\x18\x01 \x01(\t\x12\x13\n\x0b\x65nsembleUID\x18\x02 \x01(\t\x12\x17\n\x0f\x66uncAssemblyUID\x18\x03 \x03(\t\x12\x12\n\ndatasetUID\x18\x04 \x01(\t\x12\x10\n\x08probeUID\x18\x05 \x01(\t\"\x8b\x01\n\x10NeuronStatistics\x12\x1a\n\x12WaveformAvgAbsAmpl\x18\x01 \x02(\x01\x12\x0b\n\x03Snr\x18\x02 \x02(\x01\x12\x12\n\nspikeCount\x18\x03 \x02(\x03\x12\x14\n\x0c\x61vgSpikeRate\x18\x04 \x02(\x01\x12$\n\x04isih\x18\x05 \x01(\x0b\x32\x16.allego.NeuronHistData\"|\n\x0fSpikeDescriptor\x12\x11\n\ttimestamp\x18\x01 \x02(\x03\x12\r\n\x05label\x18\x02 \x02(\t\x12\x10\n\x08waveform\x18\x03 \x03(\x02\x12\x10\n\x08\x66\x65\x61tures\x18\x04 \x03(\x02\x12\x13\n\x0b\x64\x65\x63\x46\x65\x61tures\x18\x05 \x03(\x01\x12\x0e\n\x06zscore\x18\x06 \x03(\x02\"g\n\tSpikeData\x12&\n\x05spike\x18\x01 \x03(\x0b\x32\x17.allego.SpikeDescriptor\x12\x18\n\x10waveformMaxValue\x18\x02 \x02(\x02\x12\x18\n\x10waveformMinValue\x18\x03 \x02(\x02\"1\n\rSpikeTimeData\x12\x11\n\tspikeTime\x18\x01 \x03(\x01\x12\r\n\x05label\x18\x02 \x03(\x05\"Q\n\x12SpikeTimestampData\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x05\x12\x17\n\x0fspikeTimestamps\x18\x02 \x03(\x03\x12\x0e\n\x06labels\x18\x03 \x03(\x05\"\xb6\x02\n\x17SpikeTemplateDescriptor\x12\x10\n\x08neuronID\x18\x01 \x02(\t\x12\r\n\x05label\x18\x02 \x02(\t\x12\x11\n\tnumSpikes\x18\x03 \x02(\x03\x12\x10\n\x08waveform\x18\x04 \x02(\x0c\x12\x12\n\nwaveformSd\x18\x05 \x02(\x0c\x12\x13\n\x0blenWaveform\x18\x06 \x02(\x03\x12\x10\n\x08\x66\x65\x61tures\x18\x07 \x02(\x0c\x12\x12\n\nfeaturesSd\x18\x08 \x02(\x0c\x12\x13\n\x0blenFeatures\x18\t \x02(\x03\x12\x11\n\tfeatures2\x18\n \x02(\x0c\x12\x13\n\x0b\x66\x65\x61tures2Sd\x18\x0b \x02(\x0c\x12\x14\n\x0clenFeatures2\x18\x0c \x02(\x03\x12\x0e\n\x06zscore\x18\r \x02(\x0c\x12\x10\n\x08zscoreSd\x18\x0e \x02(\x0c\x12\x11\n\tlenZscore\x18\x0f \x02(\x03\"[\n\x12SiteSpikeTemplates\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x05\x12\x31\n\x08template\x18\x02 \x03(\x0b\x32\x1f.allego.SpikeTemplateDescriptor\"\x97\x01\n\x1f\x42iointerfaceSpikeTemplatesReply\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x10\n\x08sampFreq\x18\x02 \x02(\x01\x12\x11\n\ttimeRange\x18\x03 \x03(\x01\x12\x12\n\nntvChanIdx\x18\x04 \x03(\x05\x12(\n\x04site\x18\x05 \x03(\x0b\x32\x1a.allego.SiteSpikeTemplates\"@\n\x14\x42iointerfaceMetaData\x12(\n\x0bsignalGroup\x18\x01 \x01(\x0b\x32\x13.allego.SignalGroup\"\xd6\x01\n\x1a\x42iointerfaceSpikeDataReply\x12\x16\n\x0e\x62iointerfaceID\x18\x01 \x02(\t\x12\x10\n\x08sampFreq\x18\x02 \x02(\x01\x12\x11\n\ttimeRange\x18\x03 \x03(\x01\x12\x16\n\x0etimestampRange\x18\x04 \x03(\x03\x12\x12\n\nntvChanIdx\x18\x05 \x03(\x05\x12\x1f\n\x04site\x18\x06 \x03(\x0b\x32\x11.allego.SpikeData\x12.\n\x08metaData\x18\x07 \x01(\x0b\x32\x1c.allego.BiointerfaceMetaData\"y\n\x1fSpikeDataDenseChannelDescriptor\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x05\x12\x0e\n\x06labels\x18\x02 \x03(\x05\x12\x18\n\x10waveformMaxValue\x18\x03 \x02(\x02\x12\x18\n\x10waveformMinValue\x18\x04 \x02(\x02\"\xb6\x01\n\x1f\x42iointerfaceSpikeDataDenseReply\x12\x11\n\ttimeRange\x18\x01 \x03(\x01\x12\x17\n\x0fwaveformNPoints\x18\x02 \x02(\x05\x12\x14\n\x0ctotalNSpikes\x18\x03 \x02(\x05\x12\x43\n\x12\x63hannelDescriptors\x18\x04 \x03(\x0b\x32\'.allego.SpikeDataDenseChannelDescriptor\x12\x0c\n\x04\x64\x61ta\x18\x05 \x02(\x0c\"\x8a\x01\n\x17GroupSpikeTimeDataReply\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x10\n\x08sampFreq\x18\x02 \x02(\x01\x12\x11\n\ttimeRange\x18\x03 \x03(\x01\x12\x12\n\nntvChanIdx\x18\x04 \x03(\x05\x12#\n\x04site\x18\x05 \x03(\x0b\x32\x15.allego.SpikeTimeData\"v\n\x16\x42iointerfaceSpiketrain\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x11\n\ttimeRange\x18\x02 \x03(\x01\x12\x10\n\x08sampFreq\x18\x03 \x02(\x01\x12$\n\x04site\x18\x04 \x03(\x0b\x32\x16.allego.SiteSpiketrain\"p\n\x0eSiteSpiketrain\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x05\x12\"\n\x06neuron\x18\x02 \x03(\x0b\x32\x12.allego.Spiketrain\x12\x10\n\x08sampFreq\x18\x03 \x02(\x01\x12\x14\n\x0cnumNeighbors\x18\x04 \x02(\x05\"\x8b\x02\n\nSpiketrain\x12\x10\n\x08sampFreq\x18\x01 \x02(\x01\x12\r\n\x05label\x18\x02 \x02(\x05\x12\x17\n\x0fspikeTimestamps\x18\x03 \x03(\x03\x12\x14\n\x0cwaveformData\x18\x05 \x03(\x02\x12\x15\n\rwaveformShape\x18\x06 \x03(\x05\x12\x13\n\x0b\x66\x65\x61tureData\x18\x07 \x03(\x02\x12\x14\n\x0c\x66\x65\x61tureShape\x18\x08 \x03(\x05\x12\x12\n\nzscoreData\x18\t \x03(\x02\x12\x13\n\x0bzscoreShape\x18\n \x03(\x05\x12,\n\nneuronDesc\x18\x0f \x02(\x0b\x32\x18.allego.NeuronDescriptor\x12\x14\n\x0cnumNeighbors\x18\x11 \x02(\x05\"\xb6\x01\n\x0eNeuronHistData\x12\x13\n\x0b\x62inWidthSec\x18\x01 \x02(\x01\x12\x15\n\rhistTimeRange\x18\x02 \x03(\x01\x12%\n\x04mode\x18\x03 \x02(\x0e\x32\x17.allego.HistScalingMode\x12\x14\n\x0cnumRefEvents\x18\x04 \x02(\x03\x12\x11\n\tnumSpikes\x18\x05 \x02(\x03\x12\x1a\n\x12numProcessedSpikes\x18\x06 \x02(\x03\x12\x0c\n\x04hist\x18\x07 \x03(\x01\"\x9d\x01\n\x0cSiteHistData\x12\x14\n\x0csitePosProbe\x18\x01 \x03(\x01\x12\x14\n\x0csitePosBrain\x18\x02 \x03(\x01\x12(\n\x06neuron\x18\x03 \x03(\x0b\x32\x18.allego.NeuronDescriptor\x12$\n\x04hist\x18\x04 \x03(\x0b\x32\x16.allego.NeuronHistData\x12\x11\n\ttimeRange\x18\x05 \x03(\x01\"\x8b\x01\n\x19\x42iointerfaceHistDataReply\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x10\n\x08sampFreq\x18\x02 \x02(\x01\x12\x11\n\ttimeRange\x18\x03 \x03(\x01\x12\x12\n\nntvChanIdx\x18\x04 \x03(\x05\x12\"\n\x04site\x18\x05 \x03(\x0b\x32\x14.allego.SiteHistData\"\xb4\x01\n\x17\x42iointerfaceSaveRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x0c\n\x04path\x18\x02 \x02(\t\x12\x10\n\x08\x62\x61seName\x18\x03 \x02(\t\x12\x11\n\ttimeRange\x18\x04 \x03(\x01\x12\x33\n\tspikeComp\x18\x05 \x03(\x0e\x32 .allego.SpikeDescriptorComponent\x12\x1e\n\x16includeNeuronTemplates\x18\x06 \x02(\x08\"\xac\x01\n\x17\x42iointerfaceLoadRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x0c\n\x04path\x18\x02 \x02(\t\x12\x10\n\x08\x62\x61seName\x18\x03 \x02(\t\x12\x13\n\x0buidFragment\x18\x04 \x02(\t\x12\x33\n\tspikeComp\x18\x05 \x03(\x0e\x32 .allego.SpikeDescriptorComponent\x12\x14\n\x0c\x66orceReplace\x18\x06 \x02(\x08\"\x95\x01\n\x19\x42iointerfaceSaveLoadReply\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x0c\n\x04path\x18\x02 \x02(\t\x12\x10\n\x08\x62\x61seName\x18\x03 \x02(\t\x12\x0b\n\x03uid\x18\x04 \x02(\t\x12\x1c\n\x14\x62iointerfaceMetaFile\x18\x05 \x02(\t\x12\x1a\n\x12neuronTemplateFile\x18\x06 \x02(\t\"2\n\x17\x42iointerfaceGetIDsReply\x12\x17\n\x0f\x62iointerfaceIDs\x18\x01 \x03(\t\"\xef\x01\n\x16\x42iointerfaceVizRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x35\n\x07vizType\x18\x02 \x02(\x0e\x32$.allego.BiointerfaceVizRequest.VType\x12\x12\n\nnumSamples\x18\x03 \x02(\x05\x12\x14\n\x0cisYAutoScale\x18\x04 \x02(\x08\x12\x0c\n\x04yLim\x18\x05 \x03(\x01\x12\x0e\n\x06\x66igDir\x18\x06 \x01(\t\x12\x12\n\nisAutoOpen\x18\x07 \x01(\x08\"/\n\x05VType\x12\x15\n\x11VIZ_BIO_TEMPLATES\x10\x00\x12\x0f\n\x0bVIZ_BIO_DEV\x10\x01\"2\n\x14\x42iointerfaceVizReply\x12\x1a\n\x12pngPathAndFileName\x18\x01 \x01(\t*T\n\x10\x42iointerfaceType\x12\x13\n\x0f\x42IO_SPIKETRAINS\x10\x00\x12\x14\n\x10\x42IO_SPIKES_CACHE\x10\x01\x12\x15\n\x11\x42IO_SPIKES_STREAM\x10\x02* \n\x12SpikesImportSchema\x12\n\n\x06NI_SIM\x10\x00*@\n\x13\x42iointerfaceCommand\x12\x13\n\x0f\x42IO_CMD_SAVE_ON\x10\x00\x12\x14\n\x10\x42IO_CMD_SAVE_OFF\x10\x01*J\n\x11\x42iointerfaceState\x12\x0f\n\x0b\x42IO_SAVE_ON\x10\x00\x12\x10\n\x0c\x42IO_SAVE_OFF\x10\x01\x12\x12\n\x0e\x42IO_CONFIGURED\x10\x02*X\n\x11NeuronsSignalMode\x12\n\n\x06Spikes\x10\x00\x12\x13\n\x0fSpikeTimestamps\x10\x01\x12\x0e\n\nSpikeTimes\x10\x02\x12\x12\n\x0eSpikeWaveforms\x10\x03*q\n\x18SpikeDescriptorComponent\x12\x0e\n\nCTimestamp\x10\x00\x12\n\n\x06\x43Label\x10\x01\x12\r\n\tCWaveform\x10\x02\x12\x0c\n\x08\x43\x46\x65\x61ture\x10\x03\x12\x0f\n\x0b\x43\x44\x65\x63\x46\x65\x61ture\x10\x04\x12\x0b\n\x07\x43Zscore\x10\x05*S\n\x0fHistScalingMode\x12\x0c\n\x08\x41sSpikes\x10\x00\x12\x0f\n\x0b\x41sSpikeRate\x10\x01\x12\n\n\x06\x41sNorm\x10\x02\x12\n\n\x06\x41sProb\x10\x03\x12\t\n\x05\x41sRaw\x10\x04\x42\x15Z\x13internal/radix/grpc')

_BIOINTERFACETYPE = DESCRIPTOR.enum_types_by_name['BiointerfaceType']
BiointerfaceType = enum_type_wrapper.EnumTypeWrapper(_BIOINTERFACETYPE)
_SPIKESIMPORTSCHEMA = DESCRIPTOR.enum_types_by_name['SpikesImportSchema']
SpikesImportSchema = enum_type_wrapper.EnumTypeWrapper(_SPIKESIMPORTSCHEMA)
_BIOINTERFACECOMMAND = DESCRIPTOR.enum_types_by_name['BiointerfaceCommand']
BiointerfaceCommand = enum_type_wrapper.EnumTypeWrapper(_BIOINTERFACECOMMAND)
_BIOINTERFACESTATE = DESCRIPTOR.enum_types_by_name['BiointerfaceState']
BiointerfaceState = enum_type_wrapper.EnumTypeWrapper(_BIOINTERFACESTATE)
_NEURONSSIGNALMODE = DESCRIPTOR.enum_types_by_name['NeuronsSignalMode']
NeuronsSignalMode = enum_type_wrapper.EnumTypeWrapper(_NEURONSSIGNALMODE)
_SPIKEDESCRIPTORCOMPONENT = DESCRIPTOR.enum_types_by_name['SpikeDescriptorComponent']
SpikeDescriptorComponent = enum_type_wrapper.EnumTypeWrapper(_SPIKEDESCRIPTORCOMPONENT)
_HISTSCALINGMODE = DESCRIPTOR.enum_types_by_name['HistScalingMode']
HistScalingMode = enum_type_wrapper.EnumTypeWrapper(_HISTSCALINGMODE)
BIO_SPIKETRAINS = 0
BIO_SPIKES_CACHE = 1
BIO_SPIKES_STREAM = 2
NI_SIM = 0
BIO_CMD_SAVE_ON = 0
BIO_CMD_SAVE_OFF = 1
BIO_SAVE_ON = 0
BIO_SAVE_OFF = 1
BIO_CONFIGURED = 2
Spikes = 0
SpikeTimestamps = 1
SpikeTimes = 2
SpikeWaveforms = 3
CTimestamp = 0
CLabel = 1
CWaveform = 2
CFeature = 3
CDecFeature = 4
CZscore = 5
AsSpikes = 0
AsSpikeRate = 1
AsNorm = 2
AsProb = 3
AsRaw = 4


_SPIKESSTDREQ = DESCRIPTOR.message_types_by_name['SpikesStdReq']
_SPIKESNEWLOADREPLY = DESCRIPTOR.message_types_by_name['SpikesNewLoadReply']
_SPIKESRENAMEREQ = DESCRIPTOR.message_types_by_name['SpikesRenameReq']
_SPIKESGETIDSREPLY = DESCRIPTOR.message_types_by_name['SpikesGetIDsReply']
_SPIKESSPECREPLY = DESCRIPTOR.message_types_by_name['SpikesSpecReply']
_SPIKESSITESPEC = DESCRIPTOR.message_types_by_name['SpikesSiteSpec']
_SPIKELABELRECORD = DESCRIPTOR.message_types_by_name['SpikeLabelRecord']
_SPIKEMATRIX = DESCRIPTOR.message_types_by_name['SpikeMatrix']
_SPIKEMATRIXSET = DESCRIPTOR.message_types_by_name['SpikeMatrixSet']
_NEURONSPIKEMATRIXSET = DESCRIPTOR.message_types_by_name['NeuronSpikeMatrixSet']
_BIOINTERFACEGETSPIKESREQUEST = DESCRIPTOR.message_types_by_name['BiointerfaceGetSpikesRequest']
_BIOINTERFACEGETHISTREQUEST = DESCRIPTOR.message_types_by_name['BiointerfaceGetHistRequest']
_BIOINTERFACEGETSPIKETIMESTAMPSREQUEST = DESCRIPTOR.message_types_by_name['BiointerfaceGetSpikeTimestampsRequest']
_BIOINTERFACESPIKETIMESTAMPSREPLY = DESCRIPTOR.message_types_by_name['BiointerfaceSpikeTimestampsReply']
_BIOINTERFACESEEKENDSPIKETIMESTAMPSREQUEST = DESCRIPTOR.message_types_by_name['BiointerfaceSeekEndSpikeTimestampsRequest']
_BIOINTERFACEGETNEURONSREQUEST = DESCRIPTOR.message_types_by_name['BiointerfaceGetNeuronsRequest']
_BIOINTERFACEGETNEURONSREPLY = DESCRIPTOR.message_types_by_name['BiointerfaceGetNeuronsReply']
_BIOINTERFACEGETNEURONSREPLY_SPIKERATECHUNK = _BIOINTERFACEGETNEURONSREPLY.nested_types_by_name['SpikeRateChunk']
_BIOINTERFACEGETNEURONSREPLY_NEURONL = _BIOINTERFACEGETNEURONSREPLY.nested_types_by_name['NeuronL']
_BIOINTERFACEGETNEURONSREPLY_SITEENTRY = _BIOINTERFACEGETNEURONSREPLY.nested_types_by_name['SiteEntry']
_SPIKESSITESTATS = DESCRIPTOR.message_types_by_name['SpikesSiteStats']
_SPIKECOMPONENTLEN = DESCRIPTOR.message_types_by_name['SpikeComponentLen']
_NEIGHBORDESCRIPTOR = DESCRIPTOR.message_types_by_name['NeighborDescriptor']
_NEURONDESCRIPTOR = DESCRIPTOR.message_types_by_name['NeuronDescriptor']
_NEURONEXTENDEDMETADATA = DESCRIPTOR.message_types_by_name['NeuronExtendedMetadata']
_NEURONSTATISTICS = DESCRIPTOR.message_types_by_name['NeuronStatistics']
_SPIKEDESCRIPTOR = DESCRIPTOR.message_types_by_name['SpikeDescriptor']
_SPIKEDATA = DESCRIPTOR.message_types_by_name['SpikeData']
_SPIKETIMEDATA = DESCRIPTOR.message_types_by_name['SpikeTimeData']
_SPIKETIMESTAMPDATA = DESCRIPTOR.message_types_by_name['SpikeTimestampData']
_SPIKETEMPLATEDESCRIPTOR = DESCRIPTOR.message_types_by_name['SpikeTemplateDescriptor']
_SITESPIKETEMPLATES = DESCRIPTOR.message_types_by_name['SiteSpikeTemplates']
_BIOINTERFACESPIKETEMPLATESREPLY = DESCRIPTOR.message_types_by_name['BiointerfaceSpikeTemplatesReply']
_BIOINTERFACEMETADATA = DESCRIPTOR.message_types_by_name['BiointerfaceMetaData']
_BIOINTERFACESPIKEDATAREPLY = DESCRIPTOR.message_types_by_name['BiointerfaceSpikeDataReply']
_SPIKEDATADENSECHANNELDESCRIPTOR = DESCRIPTOR.message_types_by_name['SpikeDataDenseChannelDescriptor']
_BIOINTERFACESPIKEDATADENSEREPLY = DESCRIPTOR.message_types_by_name['BiointerfaceSpikeDataDenseReply']
_GROUPSPIKETIMEDATAREPLY = DESCRIPTOR.message_types_by_name['GroupSpikeTimeDataReply']
_BIOINTERFACESPIKETRAIN = DESCRIPTOR.message_types_by_name['BiointerfaceSpiketrain']
_SITESPIKETRAIN = DESCRIPTOR.message_types_by_name['SiteSpiketrain']
_SPIKETRAIN = DESCRIPTOR.message_types_by_name['Spiketrain']
_NEURONHISTDATA = DESCRIPTOR.message_types_by_name['NeuronHistData']
_SITEHISTDATA = DESCRIPTOR.message_types_by_name['SiteHistData']
_BIOINTERFACEHISTDATAREPLY = DESCRIPTOR.message_types_by_name['BiointerfaceHistDataReply']
_BIOINTERFACESAVEREQUEST = DESCRIPTOR.message_types_by_name['BiointerfaceSaveRequest']
_BIOINTERFACELOADREQUEST = DESCRIPTOR.message_types_by_name['BiointerfaceLoadRequest']
_BIOINTERFACESAVELOADREPLY = DESCRIPTOR.message_types_by_name['BiointerfaceSaveLoadReply']
_BIOINTERFACEGETIDSREPLY = DESCRIPTOR.message_types_by_name['BiointerfaceGetIDsReply']
_BIOINTERFACEVIZREQUEST = DESCRIPTOR.message_types_by_name['BiointerfaceVizRequest']
_BIOINTERFACEVIZREPLY = DESCRIPTOR.message_types_by_name['BiointerfaceVizReply']
_BIOINTERFACEVIZREQUEST_VTYPE = _BIOINTERFACEVIZREQUEST.enum_types_by_name['VType']
SpikesStdReq = _reflection.GeneratedProtocolMessageType('SpikesStdReq', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESSTDREQ,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikesStdReq)
  })
_sym_db.RegisterMessage(SpikesStdReq)

SpikesNewLoadReply = _reflection.GeneratedProtocolMessageType('SpikesNewLoadReply', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESNEWLOADREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikesNewLoadReply)
  })
_sym_db.RegisterMessage(SpikesNewLoadReply)

SpikesRenameReq = _reflection.GeneratedProtocolMessageType('SpikesRenameReq', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESRENAMEREQ,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikesRenameReq)
  })
_sym_db.RegisterMessage(SpikesRenameReq)

SpikesGetIDsReply = _reflection.GeneratedProtocolMessageType('SpikesGetIDsReply', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESGETIDSREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikesGetIDsReply)
  })
_sym_db.RegisterMessage(SpikesGetIDsReply)

SpikesSpecReply = _reflection.GeneratedProtocolMessageType('SpikesSpecReply', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESSPECREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikesSpecReply)
  })
_sym_db.RegisterMessage(SpikesSpecReply)

SpikesSiteSpec = _reflection.GeneratedProtocolMessageType('SpikesSiteSpec', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESSITESPEC,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikesSiteSpec)
  })
_sym_db.RegisterMessage(SpikesSiteSpec)

SpikeLabelRecord = _reflection.GeneratedProtocolMessageType('SpikeLabelRecord', (_message.Message,), {
  'DESCRIPTOR' : _SPIKELABELRECORD,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeLabelRecord)
  })
_sym_db.RegisterMessage(SpikeLabelRecord)

SpikeMatrix = _reflection.GeneratedProtocolMessageType('SpikeMatrix', (_message.Message,), {
  'DESCRIPTOR' : _SPIKEMATRIX,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeMatrix)
  })
_sym_db.RegisterMessage(SpikeMatrix)

SpikeMatrixSet = _reflection.GeneratedProtocolMessageType('SpikeMatrixSet', (_message.Message,), {
  'DESCRIPTOR' : _SPIKEMATRIXSET,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeMatrixSet)
  })
_sym_db.RegisterMessage(SpikeMatrixSet)

NeuronSpikeMatrixSet = _reflection.GeneratedProtocolMessageType('NeuronSpikeMatrixSet', (_message.Message,), {
  'DESCRIPTOR' : _NEURONSPIKEMATRIXSET,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.NeuronSpikeMatrixSet)
  })
_sym_db.RegisterMessage(NeuronSpikeMatrixSet)

BiointerfaceGetSpikesRequest = _reflection.GeneratedProtocolMessageType('BiointerfaceGetSpikesRequest', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACEGETSPIKESREQUEST,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceGetSpikesRequest)
  })
_sym_db.RegisterMessage(BiointerfaceGetSpikesRequest)

BiointerfaceGetHistRequest = _reflection.GeneratedProtocolMessageType('BiointerfaceGetHistRequest', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACEGETHISTREQUEST,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceGetHistRequest)
  })
_sym_db.RegisterMessage(BiointerfaceGetHistRequest)

BiointerfaceGetSpikeTimestampsRequest = _reflection.GeneratedProtocolMessageType('BiointerfaceGetSpikeTimestampsRequest', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACEGETSPIKETIMESTAMPSREQUEST,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceGetSpikeTimestampsRequest)
  })
_sym_db.RegisterMessage(BiointerfaceGetSpikeTimestampsRequest)

BiointerfaceSpikeTimestampsReply = _reflection.GeneratedProtocolMessageType('BiointerfaceSpikeTimestampsReply', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACESPIKETIMESTAMPSREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceSpikeTimestampsReply)
  })
_sym_db.RegisterMessage(BiointerfaceSpikeTimestampsReply)

BiointerfaceSeekEndSpikeTimestampsRequest = _reflection.GeneratedProtocolMessageType('BiointerfaceSeekEndSpikeTimestampsRequest', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACESEEKENDSPIKETIMESTAMPSREQUEST,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceSeekEndSpikeTimestampsRequest)
  })
_sym_db.RegisterMessage(BiointerfaceSeekEndSpikeTimestampsRequest)

BiointerfaceGetNeuronsRequest = _reflection.GeneratedProtocolMessageType('BiointerfaceGetNeuronsRequest', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACEGETNEURONSREQUEST,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceGetNeuronsRequest)
  })
_sym_db.RegisterMessage(BiointerfaceGetNeuronsRequest)

BiointerfaceGetNeuronsReply = _reflection.GeneratedProtocolMessageType('BiointerfaceGetNeuronsReply', (_message.Message,), {

  'SpikeRateChunk' : _reflection.GeneratedProtocolMessageType('SpikeRateChunk', (_message.Message,), {
    'DESCRIPTOR' : _BIOINTERFACEGETNEURONSREPLY_SPIKERATECHUNK,
    '__module__' : 'biointerface_pb2'
    # @@protoc_insertion_point(class_scope:allego.BiointerfaceGetNeuronsReply.SpikeRateChunk)
    })
  ,

  'NeuronL' : _reflection.GeneratedProtocolMessageType('NeuronL', (_message.Message,), {
    'DESCRIPTOR' : _BIOINTERFACEGETNEURONSREPLY_NEURONL,
    '__module__' : 'biointerface_pb2'
    # @@protoc_insertion_point(class_scope:allego.BiointerfaceGetNeuronsReply.NeuronL)
    })
  ,

  'SiteEntry' : _reflection.GeneratedProtocolMessageType('SiteEntry', (_message.Message,), {
    'DESCRIPTOR' : _BIOINTERFACEGETNEURONSREPLY_SITEENTRY,
    '__module__' : 'biointerface_pb2'
    # @@protoc_insertion_point(class_scope:allego.BiointerfaceGetNeuronsReply.SiteEntry)
    })
  ,
  'DESCRIPTOR' : _BIOINTERFACEGETNEURONSREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceGetNeuronsReply)
  })
_sym_db.RegisterMessage(BiointerfaceGetNeuronsReply)
_sym_db.RegisterMessage(BiointerfaceGetNeuronsReply.SpikeRateChunk)
_sym_db.RegisterMessage(BiointerfaceGetNeuronsReply.NeuronL)
_sym_db.RegisterMessage(BiointerfaceGetNeuronsReply.SiteEntry)

SpikesSiteStats = _reflection.GeneratedProtocolMessageType('SpikesSiteStats', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESSITESTATS,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikesSiteStats)
  })
_sym_db.RegisterMessage(SpikesSiteStats)

SpikeComponentLen = _reflection.GeneratedProtocolMessageType('SpikeComponentLen', (_message.Message,), {
  'DESCRIPTOR' : _SPIKECOMPONENTLEN,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeComponentLen)
  })
_sym_db.RegisterMessage(SpikeComponentLen)

NeighborDescriptor = _reflection.GeneratedProtocolMessageType('NeighborDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _NEIGHBORDESCRIPTOR,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.NeighborDescriptor)
  })
_sym_db.RegisterMessage(NeighborDescriptor)

NeuronDescriptor = _reflection.GeneratedProtocolMessageType('NeuronDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _NEURONDESCRIPTOR,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.NeuronDescriptor)
  })
_sym_db.RegisterMessage(NeuronDescriptor)

NeuronExtendedMetadata = _reflection.GeneratedProtocolMessageType('NeuronExtendedMetadata', (_message.Message,), {
  'DESCRIPTOR' : _NEURONEXTENDEDMETADATA,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.NeuronExtendedMetadata)
  })
_sym_db.RegisterMessage(NeuronExtendedMetadata)

NeuronStatistics = _reflection.GeneratedProtocolMessageType('NeuronStatistics', (_message.Message,), {
  'DESCRIPTOR' : _NEURONSTATISTICS,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.NeuronStatistics)
  })
_sym_db.RegisterMessage(NeuronStatistics)

SpikeDescriptor = _reflection.GeneratedProtocolMessageType('SpikeDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _SPIKEDESCRIPTOR,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeDescriptor)
  })
_sym_db.RegisterMessage(SpikeDescriptor)

SpikeData = _reflection.GeneratedProtocolMessageType('SpikeData', (_message.Message,), {
  'DESCRIPTOR' : _SPIKEDATA,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeData)
  })
_sym_db.RegisterMessage(SpikeData)

SpikeTimeData = _reflection.GeneratedProtocolMessageType('SpikeTimeData', (_message.Message,), {
  'DESCRIPTOR' : _SPIKETIMEDATA,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeTimeData)
  })
_sym_db.RegisterMessage(SpikeTimeData)

SpikeTimestampData = _reflection.GeneratedProtocolMessageType('SpikeTimestampData', (_message.Message,), {
  'DESCRIPTOR' : _SPIKETIMESTAMPDATA,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeTimestampData)
  })
_sym_db.RegisterMessage(SpikeTimestampData)

SpikeTemplateDescriptor = _reflection.GeneratedProtocolMessageType('SpikeTemplateDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _SPIKETEMPLATEDESCRIPTOR,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeTemplateDescriptor)
  })
_sym_db.RegisterMessage(SpikeTemplateDescriptor)

SiteSpikeTemplates = _reflection.GeneratedProtocolMessageType('SiteSpikeTemplates', (_message.Message,), {
  'DESCRIPTOR' : _SITESPIKETEMPLATES,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SiteSpikeTemplates)
  })
_sym_db.RegisterMessage(SiteSpikeTemplates)

BiointerfaceSpikeTemplatesReply = _reflection.GeneratedProtocolMessageType('BiointerfaceSpikeTemplatesReply', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACESPIKETEMPLATESREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceSpikeTemplatesReply)
  })
_sym_db.RegisterMessage(BiointerfaceSpikeTemplatesReply)

BiointerfaceMetaData = _reflection.GeneratedProtocolMessageType('BiointerfaceMetaData', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACEMETADATA,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceMetaData)
  })
_sym_db.RegisterMessage(BiointerfaceMetaData)

BiointerfaceSpikeDataReply = _reflection.GeneratedProtocolMessageType('BiointerfaceSpikeDataReply', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACESPIKEDATAREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceSpikeDataReply)
  })
_sym_db.RegisterMessage(BiointerfaceSpikeDataReply)

SpikeDataDenseChannelDescriptor = _reflection.GeneratedProtocolMessageType('SpikeDataDenseChannelDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _SPIKEDATADENSECHANNELDESCRIPTOR,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeDataDenseChannelDescriptor)
  })
_sym_db.RegisterMessage(SpikeDataDenseChannelDescriptor)

BiointerfaceSpikeDataDenseReply = _reflection.GeneratedProtocolMessageType('BiointerfaceSpikeDataDenseReply', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACESPIKEDATADENSEREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceSpikeDataDenseReply)
  })
_sym_db.RegisterMessage(BiointerfaceSpikeDataDenseReply)

GroupSpikeTimeDataReply = _reflection.GeneratedProtocolMessageType('GroupSpikeTimeDataReply', (_message.Message,), {
  'DESCRIPTOR' : _GROUPSPIKETIMEDATAREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.GroupSpikeTimeDataReply)
  })
_sym_db.RegisterMessage(GroupSpikeTimeDataReply)

BiointerfaceSpiketrain = _reflection.GeneratedProtocolMessageType('BiointerfaceSpiketrain', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACESPIKETRAIN,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceSpiketrain)
  })
_sym_db.RegisterMessage(BiointerfaceSpiketrain)

SiteSpiketrain = _reflection.GeneratedProtocolMessageType('SiteSpiketrain', (_message.Message,), {
  'DESCRIPTOR' : _SITESPIKETRAIN,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SiteSpiketrain)
  })
_sym_db.RegisterMessage(SiteSpiketrain)

Spiketrain = _reflection.GeneratedProtocolMessageType('Spiketrain', (_message.Message,), {
  'DESCRIPTOR' : _SPIKETRAIN,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.Spiketrain)
  })
_sym_db.RegisterMessage(Spiketrain)

NeuronHistData = _reflection.GeneratedProtocolMessageType('NeuronHistData', (_message.Message,), {
  'DESCRIPTOR' : _NEURONHISTDATA,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.NeuronHistData)
  })
_sym_db.RegisterMessage(NeuronHistData)

SiteHistData = _reflection.GeneratedProtocolMessageType('SiteHistData', (_message.Message,), {
  'DESCRIPTOR' : _SITEHISTDATA,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SiteHistData)
  })
_sym_db.RegisterMessage(SiteHistData)

BiointerfaceHistDataReply = _reflection.GeneratedProtocolMessageType('BiointerfaceHistDataReply', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACEHISTDATAREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceHistDataReply)
  })
_sym_db.RegisterMessage(BiointerfaceHistDataReply)

BiointerfaceSaveRequest = _reflection.GeneratedProtocolMessageType('BiointerfaceSaveRequest', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACESAVEREQUEST,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceSaveRequest)
  })
_sym_db.RegisterMessage(BiointerfaceSaveRequest)

BiointerfaceLoadRequest = _reflection.GeneratedProtocolMessageType('BiointerfaceLoadRequest', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACELOADREQUEST,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceLoadRequest)
  })
_sym_db.RegisterMessage(BiointerfaceLoadRequest)

BiointerfaceSaveLoadReply = _reflection.GeneratedProtocolMessageType('BiointerfaceSaveLoadReply', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACESAVELOADREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceSaveLoadReply)
  })
_sym_db.RegisterMessage(BiointerfaceSaveLoadReply)

BiointerfaceGetIDsReply = _reflection.GeneratedProtocolMessageType('BiointerfaceGetIDsReply', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACEGETIDSREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceGetIDsReply)
  })
_sym_db.RegisterMessage(BiointerfaceGetIDsReply)

BiointerfaceVizRequest = _reflection.GeneratedProtocolMessageType('BiointerfaceVizRequest', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACEVIZREQUEST,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceVizRequest)
  })
_sym_db.RegisterMessage(BiointerfaceVizRequest)

BiointerfaceVizReply = _reflection.GeneratedProtocolMessageType('BiointerfaceVizReply', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACEVIZREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceVizReply)
  })
_sym_db.RegisterMessage(BiointerfaceVizReply)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\023internal/radix/grpc'
  _BIOINTERFACEGETNEURONSREPLY_SITEENTRY._options = None
  _BIOINTERFACEGETNEURONSREPLY_SITEENTRY._serialized_options = b'8\001'
  _BIOINTERFACETYPE._serialized_start=7744
  _BIOINTERFACETYPE._serialized_end=7828
  _SPIKESIMPORTSCHEMA._serialized_start=7830
  _SPIKESIMPORTSCHEMA._serialized_end=7862
  _BIOINTERFACECOMMAND._serialized_start=7864
  _BIOINTERFACECOMMAND._serialized_end=7928
  _BIOINTERFACESTATE._serialized_start=7930
  _BIOINTERFACESTATE._serialized_end=8004
  _NEURONSSIGNALMODE._serialized_start=8006
  _NEURONSSIGNALMODE._serialized_end=8094
  _SPIKEDESCRIPTORCOMPONENT._serialized_start=8096
  _SPIKEDESCRIPTORCOMPONENT._serialized_end=8209
  _HISTSCALINGMODE._serialized_start=8211
  _HISTSCALINGMODE._serialized_end=8294
  _SPIKESSTDREQ._serialized_start=44
  _SPIKESSTDREQ._serialized_end=77
  _SPIKESNEWLOADREPLY._serialized_start=79
  _SPIKESNEWLOADREPLY._serialized_end=99
  _SPIKESRENAMEREQ._serialized_start=101
  _SPIKESRENAMEREQ._serialized_end=161
  _SPIKESGETIDSREPLY._serialized_start=163
  _SPIKESGETIDSREPLY._serialized_end=182
  _SPIKESSPECREPLY._serialized_start=185
  _SPIKESSPECREPLY._serialized_end=732
  _SPIKESSITESPEC._serialized_start=735
  _SPIKESSITESPEC._serialized_end=1316
  _SPIKELABELRECORD._serialized_start=1318
  _SPIKELABELRECORD._serialized_end=1351
  _SPIKEMATRIX._serialized_start=1354
  _SPIKEMATRIX._serialized_end=1636
  _SPIKEMATRIXSET._serialized_start=1638
  _SPIKEMATRIXSET._serialized_end=1763
  _NEURONSPIKEMATRIXSET._serialized_start=1766
  _NEURONSPIKEMATRIXSET._serialized_end=1913
  _BIOINTERFACEGETSPIKESREQUEST._serialized_start=1916
  _BIOINTERFACEGETSPIKESREQUEST._serialized_end=2192
  _BIOINTERFACEGETHISTREQUEST._serialized_start=2195
  _BIOINTERFACEGETHISTREQUEST._serialized_end=2348
  _BIOINTERFACEGETSPIKETIMESTAMPSREQUEST._serialized_start=2351
  _BIOINTERFACEGETSPIKETIMESTAMPSREQUEST._serialized_end=2495
  _BIOINTERFACESPIKETIMESTAMPSREPLY._serialized_start=2498
  _BIOINTERFACESPIKETIMESTAMPSREPLY._serialized_end=2637
  _BIOINTERFACESEEKENDSPIKETIMESTAMPSREQUEST._serialized_start=2639
  _BIOINTERFACESEEKENDSPIKETIMESTAMPSREQUEST._serialized_end=2722
  _BIOINTERFACEGETNEURONSREQUEST._serialized_start=2724
  _BIOINTERFACEGETNEURONSREQUEST._serialized_end=2813
  _BIOINTERFACEGETNEURONSREPLY._serialized_start=2816
  _BIOINTERFACEGETNEURONSREPLY._serialized_end=3172
  _BIOINTERFACEGETNEURONSREPLY_SPIKERATECHUNK._serialized_start=2908
  _BIOINTERFACEGETNEURONSREPLY_SPIKERATECHUNK._serialized_end=2962
  _BIOINTERFACEGETNEURONSREPLY_NEURONL._serialized_start=2964
  _BIOINTERFACEGETNEURONSREPLY_NEURONL._serialized_end=3082
  _BIOINTERFACEGETNEURONSREPLY_SITEENTRY._serialized_start=3084
  _BIOINTERFACEGETNEURONSREPLY_SITEENTRY._serialized_end=3172
  _SPIKESSITESTATS._serialized_start=3175
  _SPIKESSITESTATS._serialized_end=3438
  _SPIKECOMPONENTLEN._serialized_start=3440
  _SPIKECOMPONENTLEN._serialized_end=3542
  _NEIGHBORDESCRIPTOR._serialized_start=3545
  _NEIGHBORDESCRIPTOR._serialized_end=3713
  _NEURONDESCRIPTOR._serialized_start=3716
  _NEURONDESCRIPTOR._serialized_end=3959
  _NEURONEXTENDEDMETADATA._serialized_start=3962
  _NEURONEXTENDEDMETADATA._serialized_end=4096
  _NEURONSTATISTICS._serialized_start=4099
  _NEURONSTATISTICS._serialized_end=4238
  _SPIKEDESCRIPTOR._serialized_start=4240
  _SPIKEDESCRIPTOR._serialized_end=4364
  _SPIKEDATA._serialized_start=4366
  _SPIKEDATA._serialized_end=4469
  _SPIKETIMEDATA._serialized_start=4471
  _SPIKETIMEDATA._serialized_end=4520
  _SPIKETIMESTAMPDATA._serialized_start=4522
  _SPIKETIMESTAMPDATA._serialized_end=4603
  _SPIKETEMPLATEDESCRIPTOR._serialized_start=4606
  _SPIKETEMPLATEDESCRIPTOR._serialized_end=4916
  _SITESPIKETEMPLATES._serialized_start=4918
  _SITESPIKETEMPLATES._serialized_end=5009
  _BIOINTERFACESPIKETEMPLATESREPLY._serialized_start=5012
  _BIOINTERFACESPIKETEMPLATESREPLY._serialized_end=5163
  _BIOINTERFACEMETADATA._serialized_start=5165
  _BIOINTERFACEMETADATA._serialized_end=5229
  _BIOINTERFACESPIKEDATAREPLY._serialized_start=5232
  _BIOINTERFACESPIKEDATAREPLY._serialized_end=5446
  _SPIKEDATADENSECHANNELDESCRIPTOR._serialized_start=5448
  _SPIKEDATADENSECHANNELDESCRIPTOR._serialized_end=5569
  _BIOINTERFACESPIKEDATADENSEREPLY._serialized_start=5572
  _BIOINTERFACESPIKEDATADENSEREPLY._serialized_end=5754
  _GROUPSPIKETIMEDATAREPLY._serialized_start=5757
  _GROUPSPIKETIMEDATAREPLY._serialized_end=5895
  _BIOINTERFACESPIKETRAIN._serialized_start=5897
  _BIOINTERFACESPIKETRAIN._serialized_end=6015
  _SITESPIKETRAIN._serialized_start=6017
  _SITESPIKETRAIN._serialized_end=6129
  _SPIKETRAIN._serialized_start=6132
  _SPIKETRAIN._serialized_end=6399
  _NEURONHISTDATA._serialized_start=6402
  _NEURONHISTDATA._serialized_end=6584
  _SITEHISTDATA._serialized_start=6587
  _SITEHISTDATA._serialized_end=6744
  _BIOINTERFACEHISTDATAREPLY._serialized_start=6747
  _BIOINTERFACEHISTDATAREPLY._serialized_end=6886
  _BIOINTERFACESAVEREQUEST._serialized_start=6889
  _BIOINTERFACESAVEREQUEST._serialized_end=7069
  _BIOINTERFACELOADREQUEST._serialized_start=7072
  _BIOINTERFACELOADREQUEST._serialized_end=7244
  _BIOINTERFACESAVELOADREPLY._serialized_start=7247
  _BIOINTERFACESAVELOADREPLY._serialized_end=7396
  _BIOINTERFACEGETIDSREPLY._serialized_start=7398
  _BIOINTERFACEGETIDSREPLY._serialized_end=7448
  _BIOINTERFACEVIZREQUEST._serialized_start=7451
  _BIOINTERFACEVIZREQUEST._serialized_end=7690
  _BIOINTERFACEVIZREQUEST_VTYPE._serialized_start=7643
  _BIOINTERFACEVIZREQUEST_VTYPE._serialized_end=7690
  _BIOINTERFACEVIZREPLY._serialized_start=7692
  _BIOINTERFACEVIZREPLY._serialized_end=7742
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: radiensserver.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from . import datasource_pb2 as datasource__pb2
from . import biointerface_pb2 as biointerface__pb2
from . import spikesorter_pb2 as spikesorter__pb2
from . import radiens_dev_pb2 as radiens__dev__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13radiensserver.proto\x12\x06\x61llego\x1a\x0c\x63ommon.proto\x1a\x10\x64\x61tasource.proto\x1a\x12\x62iointerface.proto\x1a\x11spikesorter.proto\x1a\x11radiens_dev.proto\"K\n\x19RadiensHealthcheckRequest\x12\x1a\n\x12isIncludeWarehouse\x18\x01 \x01(\x08\x12\x12\n\nisDetailed\x18\x02 \x01(\x08\"]\n\x16RadiensHealthcheckSpec\x12\x0e\n\x06\x65rrMsg\x18\x01 \x01(\t\x12\x33\n\toutfitter\x18\x02 \x01(\x0b\x32 .allego.WarehouseHealthcheckSpec2\xdd-\n\x0bRadiensCore\x12R\n\x0bHealthcheck\x12!.allego.RadiensHealthcheckRequest\x1a\x1e.allego.RadiensHealthcheckSpec\"\x00\x12>\n\nInitialize\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12\x39\n\x05\x43lose\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12L\n\x10WorkspaceControl\x12\x1f.allego.WorkspaceControlRequest\x1a\x15.allego.StandardReply\"\x00\x12T\n\x11GetRadiensServers\x12 .allego.GetRadiensServersRequest\x1a\x1b.allego.RadiensServersReply\"\x00\x12H\n\x0cGetWorkspace\x12\x1b.allego.GetWorkspaceRequest\x1a\x19.allego.GetWorkspaceReply\"\x00\x12J\n\x13GetRadixEnvironment\x12\x17.allego.StandardRequest\x1a\x18.allego.RadixEnvironment\"\x00\x12H\n\rListDirectory\x12\x1e.allego.ListDataSourcesRequest\x1a\x15.allego.CpRmMvLsReply\"\x00\x12V\n\x12\x43opyDataSourceFile\x12\'.allego.CopyRemoveDataSourceFileRequest\x1a\x15.allego.CpRmMvLsReply\"\x00\x12X\n\x14RemoveDataSourceFile\x12\'.allego.CopyRemoveDataSourceFileRequest\x1a\x15.allego.CpRmMvLsReply\"\x00\x12P\n\x12MoveDataSourceFile\x12!.allego.MoveDataSourceFileRequest\x1a\x15.allego.CpRmMvLsReply\"\x00\x12N\n\x13SpikesListDirectory\x12\x1e.allego.ListDataSourcesRequest\x1a\x15.allego.CpRmMvLsReply\"\x00\x12R\n\x0eSpikesCopyFile\x12\'.allego.CopyRemoveDataSourceFileRequest\x1a\x15.allego.CpRmMvLsReply\"\x00\x12T\n\x10SpikesRemoveFile\x12\'.allego.CopyRemoveDataSourceFileRequest\x1a\x15.allego.CpRmMvLsReply\"\x00\x12L\n\x0eSpikesMoveFile\x12!.allego.MoveDataSourceFileRequest\x1a\x15.allego.CpRmMvLsReply\"\x00\x12T\n\x16ManageNodeOrganization\x12\x1c.allego.ManageNodeOrgRequest\x1a\x1a.allego.ManageNodeOrgReply\"\x00\x12K\n\rManageNodeLab\x12\x1c.allego.ManageNodeLabRequest\x1a\x1a.allego.ManageNodeLabReply\"\x00\x12N\n\x0eManageNodeUser\x12\x1d.allego.ManageNodeUserRequest\x1a\x1b.allego.ManageNodeUserReply\"\x00\x12\x45\n\x0fManageNodeProbe\x12\x18.allego.ProbeNodeRequest\x1a\x16.allego.ProbeNodeReply\"\x00\x12\x41\n\x0bManageEdges\x12\x18.allego.WorldEdgeRequest\x1a\x16.allego.WorldEdgeReply\"\x00\x12\x42\n\nQueryWorld\x12\x19.allego.QueryWorldRequest\x1a\x17.allego.QueryWorldReply\"\x00\x12V\n\x1bGetWarehouseSensorComponent\x12\x19.allego.SensorCompRequest\x1a\x1a.allego.GetSensorCompReply\"\x00\x12O\n\x0fListSensorSpecs\x12\x1c.allego.SignalGroupIDRequest\x1a\x1c.allego.ListSensorSpecsReply\"\x00\x12>\n\tSetSensor\x12\x18.allego.SetSensorRequest\x1a\x15.allego.StandardReply\"\x00\x12T\n\x14SetSensorPositionTcs\x12#.allego.SetSensorPositionTcsRequest\x1a\x15.allego.StandardReply\"\x00\x12R\n\x13SetSitePositionsTcs\x12\".allego.SetSitePositionsTcsRequest\x1a\x15.allego.StandardReply\"\x00\x12N\n\x11UpdateSignalGroup\x12 .allego.UpdateSignalGroupRequest\x1a\x15.allego.StandardReply\"\x00\x12N\n\x11GetSignalGroupIDs\x12\x17.allego.StandardRequest\x1a\x1e.allego.GetSignalGroupIDsReply\"\x00\x12\x45\n\x0eGetSignalGroup\x12\x1c.allego.SignalGroupIDRequest\x1a\x13.allego.SignalGroup\"\x00\x12O\n\x13GetDataSourceParams\x12\x1c.allego.SignalGroupIDRequest\x1a\x18.allego.DataSourceParams\"\x00\x12=\n\nGetSignals\x12\x19.allego.GetSignalsRequest\x1a\x12.allego.RawSignals\"\x00\x12\x41\n\x0cSetDACStream\x12\x18.allego.DACStreamRequest\x1a\x15.allego.StandardReply\"\x00\x12@\n\rGetHDSnapshot\x12\x19.allego.HDSnapshotRequest\x1a\x12.allego.HDSnapshot\"\x00\x12\x42\n\x0bSetDSPGroup\x12\x1a.allego.SetDSPGroupRequest\x1a\x15.allego.StandardReply\"\x00\x12?\n\x0bGetDSPGroup\x12\x1c.allego.SignalGroupIDRequest\x1a\x10.allego.DSPGroup\"\x00\x12J\n\x0eListDataSource\x12\x19.allego.DataSourceRequest\x1a\x1b.allego.DataSourceStatusMap\"\x00\x12K\n\x11ListDataSourceIDs\x12\x19.allego.DataSourceRequest\x1a\x19.allego.DataSourceIDReply\"\x00\x12[\n\x15SetDataSourceFromFile\x12 .allego.DataSourceSetSaveRequest\x1a\x1e.allego.DataSourceSetSaveReply\"\x00\x12I\n\x0f\x43learDataSource\x12\x19.allego.DataSourceRequest\x1a\x19.allego.DataSourceIDReply\"\x00\x12J\n\x10RenameDataSource\x12\x19.allego.DataSourceRequest\x1a\x19.allego.DataSourceIDReply\"\x00\x12>\n\x08KpiClear\x12\x19.allego.KpiControlRequest\x1a\x15.allego.StandardReply\"\x00\x12\x42\n\x0cKpiCalculate\x12\x19.allego.KpiControlRequest\x1a\x15.allego.StandardReply\"\x00\x12\x45\n\x0cGetKpiStatus\x12\x1b.allego.GetKpiStatusRequest\x1a\x16.allego.KpiStatusReply\"\x00\x12H\n\rKpiGetMetrics\x12\x15.allego.KpiMetricsReq\x1a\x1e.allego.KpiBundlePacketMetrics\"\x00\x12P\n\x12SetKpiUpdatePeriod\x12!.allego.SetKpiUpdatePeriodRequest\x1a\x15.allego.StandardReply\"\x00\x12J\n\x0fSetKpiThreshold\x12\x1e.allego.SetKpiThresholdRequest\x1a\x15.allego.StandardReply\"\x00\x12N\n\x11SetKpiEventDetect\x12 .allego.SetKpiEventDetectRequest\x1a\x15.allego.StandardReply\"\x00\x12N\n\x11SetKpiEventShadow\x12 .allego.SetKpiEventShadowRequest\x1a\x15.allego.StandardReply\"\x00\x12N\n\x11SetKpiEventWindow\x12 .allego.SetKpiEventWindowRequest\x1a\x15.allego.StandardReply\"\x00\x12U\n\x10SpikesSaveToFile\x12 .allego.DataSourceSetSaveRequest\x1a\x1d.allego.DataSourceFileSetStat\"\x00\x12W\n\x11SpikesSetFromFile\x12 .allego.DataSourceSetSaveRequest\x1a\x1e.allego.DataSourceSetSaveReply\"\x00\x12\x46\n\x0cSpikesGetIDs\x12\x19.allego.DataSourceRequest\x1a\x19.allego.DataSourceIDReply\"\x00\x12H\n\x0eSpikesRenameID\x12\x19.allego.DataSourceRequest\x1a\x19.allego.DataSourceIDReply\"\x00\x12S\n\x17SpikesGetAllSummaryInfo\x12\x19.allego.DataSourceRequest\x1a\x1b.allego.DataSourceStatusMap\"\x00\x12\x45\n\rSpikesGetSpec\x12\x19.allego.DataSourceRequest\x1a\x17.allego.SpikesSpecReply\"\x00\x12I\n\x0fSpikesDeleteIDs\x12\x19.allego.DataSourceRequest\x1a\x19.allego.DataSourceIDReply\"\x00\x12m\n\x1a\x42iointerfaceGetSpikesDense\x12$.allego.BiointerfaceGetSpikesRequest\x1a\'.allego.BiointerfaceSpikeDataDenseReply\"\x00\x12\x66\n\x16\x42iointerfaceGetNeurons\x12%.allego.BiointerfaceGetNeuronsRequest\x1a#.allego.BiointerfaceGetNeuronsReply\"\x00\x12p\n\"BiointerfaceSeekEndSpikeTimestamps\x12\x31.allego.BiointerfaceSeekEndSpikeTimestampsRequest\x1a\x15.allego.StandardReply\"\x00\x12Q\n\x0f\x42iointerfaceViz\x12\x1e.allego.BiointerfaceVizRequest\x1a\x1c.allego.BiointerfaceVizReply\"\x00\x12[\n\x1b\x42iointerfaceListSensorSpecs\x12\x1c.allego.SignalGroupIDRequest\x1a\x1c.allego.ListSensorSpecsReply\"\x00\x12J\n\x15\x42iointerfaceSetSensor\x12\x18.allego.SetSensorRequest\x1a\x15.allego.StandardReply\"\x00\x12`\n BiointerfaceSetSensorPositionTcs\x12#.allego.SetSensorPositionTcsRequest\x1a\x15.allego.StandardReply\"\x00\x12^\n\x1f\x42iointerfaceSetSitePositionsTcs\x12\".allego.SetSitePositionsTcsRequest\x1a\x15.allego.StandardReply\"\x00\x12H\n\x0c\x46\x65\x61tureStart\x12\x1f.allego.FeatureStartStopRequest\x1a\x15.allego.StandardReply\"\x00\x12G\n\x0b\x46\x65\x61tureStop\x12\x1f.allego.FeatureStartStopRequest\x1a\x15.allego.StandardReply\"\x00\x12=\n\nGetPrivacy\x12\x17.allego.StandardRequest\x1a\x14.allego.PrivacyReply\"\x00\x12@\n\nSetPrivacy\x12\x19.allego.SetPrivacyRequest\x1a\x15.allego.StandardReply\"\x00\x12J\n\x11\x44\x65leteSignalGroup\x12\x1c.allego.SignalGroupIDRequest\x1a\x15.allego.StandardReply\"\x00\x12K\n\x14SpikesGetSignalGroup\x12\x1c.allego.SignalGroupIDRequest\x1a\x13.allego.SignalGroup\"\x00\x12\x33\n\x0bSetProtocol\x12\x10.allego.Protocol\x1a\x10.allego.Protocol\"\x00\x12:\n\x0bGetProtocol\x12\x17.allego.ProtocolRequest\x1a\x10.allego.Protocol\"\x00\x12\x43\n\x0eRenameProtocol\x12\x1d.allego.RenameProtocolRequest\x1a\x10.allego.Protocol\"\x00\x12J\n\x0fGetAllProtocols\x12\x17.allego.StandardRequest\x1a\x1c.allego.GetAllProtocolsReply\"\x00\x12K\n\rApplyProtocol\x12\x17.allego.ProtocolRequest\x1a\x1d.allego.ApplyProtocolProgress\"\x00\x30\x01\x32\x98\x07\n\x13RadiensSpikeSorter1\x12R\n\x0bHealthcheck\x12!.allego.RadiensHealthcheckRequest\x1a\x1e.allego.RadiensHealthcheckSpec\"\x00\x12P\n\x12SpikeSorterCommand\x12!.allego.SpikeSorterCommandRequest\x1a\x15.allego.StandardReply\"\x00\x12R\n\x13SpikeSorterSetParam\x12\".allego.SpikeSorterSetParamRequest\x1a\x15.allego.StandardReply\"\x00\x12\x64\n\x13SpikeSorterGetParam\x12\".allego.SpikeSorterStandardRequest\x1a\'.allego.GetSpikeSorterParamCommandReply\"\x00\x12U\n\x13SpikeSorterGetState\x12\".allego.SpikeSorterStandardRequest\x1a\x18.allego.SpikeSorterState\"\x00\x12i\n\x17SpikeSorterGetDashboard\x12&.allego.SpikeSorterGetDashboardRequest\x1a$.allego.SpikeSorterGetDashboardReply\"\x00\x12i\n\x18SpikeSorterGetRasterData\x12\'.allego.SpikeSorterGetRasterDataRequest\x1a\".allego.SpikeSorterRasterDataReply\"\x00\x12I\n\x16SpikeSorterWrangleData\x12\x16.allego.WrangleRequest\x1a\x15.allego.StandardReply\"\x00\x12W\n\x11SpikeSorterLaunch\x12 .allego.SpikeSorterLaunchRequest\x1a\x1e.allego.SpikeSorterGetIDsReply\"\x00\x12P\n\x11SpikeSorterDelete\x12\".allego.SpikeSorterStandardRequest\x1a\x15.allego.StandardReply\"\x00\x32\xb7\x04\n\x0bRadiensDev1\x12R\n\x0bHealthcheck\x12!.allego.RadiensHealthcheckRequest\x1a\x1e.allego.RadiensHealthcheckSpec\"\x00\x12S\n\x1aSpkSortTrainerMakeNewModel\x12\x1c.allego.SpkSortTrainerNewReq\x1a\x15.allego.StandardReply\"\x00\x12W\n#SpkSortTrainerMakeDefaultProdModels\x12\x17.allego.StandardRequest\x1a\x15.allego.StandardReply\"\x00\x12\x64\n$SpkSortTrainerListLocalNetworkModels\x12\x17.allego.StandardRequest\x1a!.allego.SpkSortTrainerStatusReply\"\x00\x12g\n&SpkSortTrainerDeleteLocalNetworkModels\x12$.allego.SpkSortTrainerDeleteModelReq\x1a\x15.allego.StandardReply\"\x00\x12W\n\x17SpkSortTrainerGetStatus\x12\x17.allego.StandardRequest\x1a!.allego.SpkSortTrainerStatusReply\"\x00\x42\x15Z\x13internal/radix/grpc')



_RADIENSHEALTHCHECKREQUEST = DESCRIPTOR.message_types_by_name['RadiensHealthcheckRequest']
_RADIENSHEALTHCHECKSPEC = DESCRIPTOR.message_types_by_name['RadiensHealthcheckSpec']
RadiensHealthcheckRequest = _reflection.GeneratedProtocolMessageType('RadiensHealthcheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _RADIENSHEALTHCHECKREQUEST,
  '__module__' : 'radiensserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.RadiensHealthcheckRequest)
  })
_sym_db.RegisterMessage(RadiensHealthcheckRequest)

RadiensHealthcheckSpec = _reflection.GeneratedProtocolMessageType('RadiensHealthcheckSpec', (_message.Message,), {
  'DESCRIPTOR' : _RADIENSHEALTHCHECKSPEC,
  '__module__' : 'radiensserver_pb2'
  # @@protoc_insertion_point(class_scope:allego.RadiensHealthcheckSpec)
  })
_sym_db.RegisterMessage(RadiensHealthcheckSpec)

_RADIENSCORE = DESCRIPTOR.services_by_name['RadiensCore']
_RADIENSSPIKESORTER1 = DESCRIPTOR.services_by_name['RadiensSpikeSorter1']
_RADIENSDEV1 = DESCRIPTOR.services_by_name['RadiensDev1']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\023internal/radix/grpc'
  _RADIENSHEALTHCHECKREQUEST._serialized_start=121
  _RADIENSHEALTHCHECKREQUEST._serialized_end=196
  _RADIENSHEALTHCHECKSPEC._serialized_start=198
  _RADIENSHEALTHCHECKSPEC._serialized_end=291
  _RADIENSCORE._serialized_start=294
  _RADIENSCORE._serialized_end=6147
  _RADIENSSPIKESORTER1._serialized_start=6150
  _RADIENSSPIKESORTER1._serialized_end=7070
  _RADIENSDEV1._serialized_start=7073
  _RADIENSDEV1._serialized_end=7640
# @@protoc_insertion_point(module_scope)



import radiens.api.api_videre as api
import radiens.utils.config as cfg
from radiens.utils.constants import CORE_SERVICE, DEFAULT_HUB, DEFAULT_IP


class VidereClient:
    """
    A python API for Videre
    """
    def __init__(self):
        """
        """
        self.__core_port = cfg.get_radiens_core_port()
        self.hubs = {DEFAULT_HUB: {'ip_address': DEFAULT_IP, 'port': self.__core_port}}
        self.dataset_map = {}

    def add_hub(self, new_hub):
        # Add a hub (ip address of videre server)
        #   Args:
        #       hub : dict 
        #           key(s) (str): hub name(s)
        #           values (dict): {'ip_address': ip_address}
        for k in new_hub:
            if 'ip_address' in new_hub[k]:
                self.hubs[k] = {
                    'ip_address': new_hub[k]['ip_address'],
                    'port': new_hub[k]['port'] if 'port' in new_hub[k] else self.__core_port
                }
        
    def __server_address(self, hub_name, service):
        # creates server address from hub and service
        if service == 'core':
            return '{}:{}'.format(self.hubs[hub_name]['ip_address'], self.hubs[hub_name]['port'])
        else:
            raise AssertionError('invalid service name = {}'.format(service))



    # ======= API start =======
    def list_dir(self, directory, hub_name=DEFAULT_HUB):
        """
        list datasets from specified directory

        Parameters: 
            directory (Union[str, pathlib.PosixPath]): path to directory that contains dataset(s)

        Returns:
            datasets (dict): dictionary with metadata pertaining to all datasets in requested directory

        Example:
            >>> client.list_dir("Users/example/recording_data")
            {'data_source_info': {'descriptor': [{'base_name': 'allego_0__uid0823-10-56-41',
                                                'file_type': 'xdat',
                                                'path': 'Users/example/recording_data/'},
                                                {'base_name': 'allego_0__uid1014-15-03-32',
                                                'file_type': 'xdat',
                                                'path': 'Users/example/recording_data/'}],
                                'stat': [{'dataset_checksum': '62daa95366c8760122ea0706e141a67f991ee1c5605a98596c0ae859231e2683',
                                            'dataset_uid': 'ce7f4a7e-bb50-4e6b-ad0d-3ab0c5a8ea5e',
                                            'duration_sec': 14.8032,
                                            'is_meta_data_file': True,
                                            'num_bytes': 47455590,
                                            'num_bytes_meta_data': 85350,
                                            'num_bytes_primary_data': 47370240,
                                            'num_channels': 38,
                                            'num_files': 3,
                                            'sample_freq': 20000,
                                            'time_stamp': {'nanos': 53210000,
                                                        'seconds': 1661266601}},
                                        {'dataset_checksum': '9ae779f46e38a6589b84594c07f62c5f5797f13e61a1481d41f862b956c96de2',
                                            'dataset_uid': '348d18dc-e5b5-4046-8fae-d0e4f2f53566',
                                            'duration_sec': 16.5952,
                                            'is_meta_data_file': True,
                                            'num_bytes': 53189991,
                                            'num_bytes_meta_data': 85351,
                                            'num_bytes_primary_data': 53104640,
                                            'num_channels': 38,
                                            'num_files': 3,
                                            'sample_freq': 20000,
                                            'time_stamp': {'nanos': 705758000,
                                                        'seconds': 1665777812}}]},
            'dest_path': 'Users/example/recording_data',
            'msg': '',
            'num_bytes': 100645581,
            'num_dsource': 2,
            'num_files': 6}

        You can access dataset/recording information via the ``'data_source_info'`` key of the returned **datasets** dictionary. Said key
        maps to another dictionary with keys ``'descriptor'`` and ``stat`` describing various metadata. 

        Notice that there are 2 data sources (``'num_dsource'``) but 6 files total (``num_files``). This is because an xdat recording
        corresponds to 3 files with suffixes ``*.xdat.json``, ``*_data.xdat``, ``*_timestamp.xdat``.
        """
        return api.list_dir(self.__server_address(hub_name, CORE_SERVICE), directory)

    def load_dataset(self, base_name_path, hub_name=DEFAULT_HUB):
        """
        Loads a dataset on Videre 

        Parameters: 
            base_name_path (Union[str, pathlib.PosixPath]): full path and base name (no extension) to dataset

        Returns:
            dataset_id (str)

        Side effects:
            Sets value of ``dataset_id`` as key in ``dataset_map`` attribute on client. See the following example.
        
        Example:
            >>> dataset_id = client.load_dataset("/Users/example/recording_data/allego_0__uid0823-10-56-41")
            >>> client.dataset_map[dsource_id]
            {'base_name': 'allego_0__uid0823-10-56-41',
            'duration': 14.8032,
            'file_type': 'xdat',
            'num_chans': {'aux': 2, 'din': 2, 'dout': 2, 'pri': 32},
            'samp_freq': 20000.0,
            'shape': [296064, 38],
            'time_range': [0.0, 14.8032],
            'time_stamp_range': [0, 296064]}
            
        """
        dataset = api.load_dataset(self.__server_address(hub_name, CORE_SERVICE), base_name_path)
        dataset_id = dataset['dsourceID']
        status = dataset['status']
        self.dataset_map[dataset_id] = {
            'samp_freq': status['samp_freq'], 'base_name': status['base_file_name'],
            'file_type': status['file_type'], 'time_range': status['time_range'], 
            'shape': status['shape'], 'duration': status['duration'], 
            'num_chans': status['signal_group'].num_sigs, 'time_stamp_range': status['time_stamp_range']}
        return dataset_id


    def get_signals(self, dataset_id, time_range, hub_name=DEFAULT_HUB):
        """
        Gets the the signals for specified time range

        Parameters: 
            dataset_id (str): can be obtained from :py:meth:`load_dataset`
            time_range (list[float])

        Returns:
            sigarray (ndarray[numpy.float32]): raw signal data; the mapping contained in signal_group (see :py:meth:`get_signal_group`)
            time_range (list[float]) 
        """
        
        return api.get_signals(self.__server_address(hub_name, CORE_SERVICE), dataset_id, time_range)





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: datasource.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x64\x61tasource.proto\x12\x06\x61llego\x1a\x0c\x63ommon.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"<\n\x11\x44\x61taSourceRequest\x12\x11\n\tdsourceID\x18\x01 \x03(\t\x12\x14\n\x0crenameDsrcID\x18\x02 \x01(\t\"\xae\x01\n\x18\x44\x61taSourceSetSaveRequest\x12\x0c\n\x04path\x18\x01 \x02(\t\x12\x10\n\x08\x62\x61seName\x18\x02 \x02(\t\x12\x11\n\tdsourceID\x18\x03 \x01(\t\x12\x0b\n\x03uID\x18\x04 \x01(\t\x12(\n\x08\x66ileType\x18\x05 \x02(\x0e\x32\x16.allego.RadixFileTypes\x12\x0f\n\x07isForce\x18\x06 \x01(\x08\x12\x17\n\x0fisBackgroundKPI\x18\x07 \x01(\x08\"%\n\x11\x44\x61taSourceIDReply\x12\x10\n\x08sortedID\x18\x01 \x03(\t\"U\n\x16\x44\x61taSourceSetSaveReply\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12(\n\x06status\x18\x02 \x01(\x0b\x32\x18.allego.DataSourceStatus\"\xae\x01\n\x13\x44\x61taSourceStatusMap\x12\x39\n\x07\x64source\x18\x01 \x03(\x0b\x32(.allego.DataSourceStatusMap.DsourceEntry\x12\x12\n\norderedIDs\x18\x02 \x03(\t\x1aH\n\x0c\x44sourceEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.allego.DataSourceStatus:\x02\x38\x01\"\xa1\x03\n\x1f\x43opyRemoveDataSourceFileRequest\x12\x45\n\x04many\x18\x01 \x01(\x0b\x32\x35.allego.CopyRemoveDataSourceFileRequest.MultipleFilesH\x00\x12>\n\x03one\x18\x02 \x01(\x0b\x32/.allego.CopyRemoveDataSourceFileRequest.OneFileH\x00\x12\x0f\n\x07isForce\x18\x03 \x01(\x08\x12\x12\n\nisValidate\x18\x04 \x01(\x08\x1at\n\rMultipleFiles\x12#\n\x03src\x18\x01 \x03(\x0b\x32\x16.allego.FileDescriptor\x12\x10\n\x08\x64\x65stPath\x18\x02 \x01(\t\x12,\n\x0c\x64\x65stFileType\x18\x03 \x01(\x0e\x32\x16.allego.RadixFileTypes\x1aT\n\x07OneFile\x12#\n\x03src\x18\x01 \x02(\x0b\x32\x16.allego.FileDescriptor\x12$\n\x04\x64\x65st\x18\x02 \x01(\x0b\x32\x16.allego.FileDescriptorB\x06\n\x04\x64\x65sc\"\xf8\x02\n\x15\x44\x61taSourceFileSetStat\x12\x10\n\x08numFiles\x18\x01 \x02(\x05\x12\x1b\n\x13numBytesPrimaryData\x18\x02 \x02(\x03\x12\x18\n\x10numBytesMetaData\x18\x03 \x02(\x03\x12\x10\n\x08numBytes\x18\x04 \x02(\x03\x12\x16\n\x0eisMetadataFile\x18\x05 \x02(\x08\x12-\n\ttimeStamp\x18\x06 \x02(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bnumChannels\x18\x07 \x02(\x05\x12\x13\n\x0b\x64urationSec\x18\x08 \x02(\x01\x12\x12\n\ndatasetUID\x18\t \x02(\t\x12\x17\n\x0f\x64\x61tasetChecksum\x18\n \x01(\t\x12\x19\n\x11\x64\x61tasetProvenance\x18\x0b \x03(\t\x12\x12\n\nsampleRate\x18\x0c \x02(\x05\x12\x37\n\x0e\x62\x61\x63kgroundProc\x18\r \x01(\x0b\x32\x1f.allego.BackgroundProcessStatus\"\x82\x02\n\rCpRmMvLsReply\x12\x10\n\x08numFiles\x18\x01 \x02(\x05\x12\x12\n\nnumDsource\x18\x02 \x02(\x05\x12\x10\n\x08numBytes\x18\x03 \x02(\x03\x12\x10\n\x08\x64\x65stPath\x18\x04 \x02(\t\x12\x35\n\x07\x64source\x18\x05 \x03(\x0b\x32$.allego.CpRmMvLsReply.DataSourceInfo\x12\x0b\n\x03msg\x18\x06 \x01(\t\x1a\x63\n\x0e\x44\x61taSourceInfo\x12$\n\x04\x64\x65sc\x18\x01 \x02(\x0b\x32\x16.allego.FileDescriptor\x12+\n\x04stat\x18\x02 \x02(\x0b\x32\x1d.allego.DataSourceFileSetStat\"y\n\x17\x42\x61\x63kgroundProcessStatus\x12\x0b\n\x03uID\x18\x01 \x02(\t\x12\x14\n\x0c\x66racComplete\x18\x02 \x01(\x01\x12\x16\n\x0e\x65lapsedTimeSec\x18\x03 \x01(\x01\x12#\n\x1b\x65stimatedCompletionWallTime\x18\x04 \x01(\t\"\x8b\x01\n\x19MoveDataSourceFileRequest\x12#\n\x03src\x18\x01 \x02(\x0b\x32\x16.allego.FileDescriptor\x12$\n\x04\x64\x65st\x18\x02 \x02(\x0b\x32\x16.allego.FileDescriptor\x12\x0f\n\x07isForce\x18\x03 \x01(\x08\x12\x12\n\nisValidate\x18\x04 \x01(\x08\"\xe7\x02\n\x10\x44\x61taSourceStatus\x12%\n\x04type\x18\x01 \x02(\x0e\x32\x17.allego.SignalGroupType\x12\x11\n\ttimeRange\x18\x02 \x03(\x01\x12\x16\n\x0etimestampRange\x18\x03 \x03(\x03\x12\x10\n\x08\x64uration\x18\x04 \x02(\x01\x12\r\n\x05shape\x18\x05 \x03(\x03\x12(\n\x0bsignalGroup\x18\x06 \x02(\x0b\x32\x13.allego.SignalGroup\x12\x17\n\x0fnumTotalSamples\x18\x07 \x02(\x03\x12\x11\n\tsizeBytes\x18\x08 \x02(\x03\x12\x12\n\nsampleFreq\x18\t \x02(\x01\x12\x0b\n\x03uid\x18\n \x02(\t\x12\x16\n\x0e\x64\x61taSourceType\x18\x0b \x02(\t\x12\x10\n\x08\x66ileType\x18\x0c \x02(\t\x12\x0c\n\x04mode\x18\r \x02(\t\x12\r\n\x05label\x18\x0e \x02(\t\x12\x0c\n\x04path\x18\x0f \x02(\t\x12\x14\n\x0c\x62\x61seFileName\x18\x10 \x02(\t\"\xbf\x01\n\x10\x44\x61taSourceParams\x12\x12\n\nsampleFreq\x18\x01 \x02(\x01\x12\x11\n\ttimeRange\x18\x02 \x03(\x01\x12\x10\n\x08\x64uration\x18\x03 \x02(\x01\x12%\n\x04type\x18\x05 \x02(\x0e\x32\x17.allego.SignalGroupType\x12\x35\n\x0e\x64\x61tasourceType\x18\x06 \x01(\x0e\x32\x1d.allego.RadiensDatasourceType\x12\x14\n\x0c\x64\x61tasourceID\x18\x07 \x01(\t\".\n\x10ImpedanceRequest\x12\x1a\n\x04port\x18\x01 \x02(\x0e\x32\x0c.allego.Port\"\x85\x01\n\tImpedance\x12\x34\n\nimpedances\x18\x01 \x03(\x0b\x32 .allego.Impedance.ImpedanceValue\x1a\x42\n\x0eImpedanceValue\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x05\x12\x0c\n\x04zMag\x18\x02 \x02(\x01\x12\x0e\n\x06zPhase\x18\x03 \x02(\x01*<\n\x15RadiensDatasourceType\x12\x07\n\x03\x41NY\x10\x00\x12\x0e\n\nTIMESERIES\x10\x01\x12\n\n\x06SPIKES\x10\x02\x42\x15Z\x13internal/radix/grpc')

_RADIENSDATASOURCETYPE = DESCRIPTOR.enum_types_by_name['RadiensDatasourceType']
RadiensDatasourceType = enum_type_wrapper.EnumTypeWrapper(_RADIENSDATASOURCETYPE)
ANY = 0
TIMESERIES = 1
SPIKES = 2


_DATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['DataSourceRequest']
_DATASOURCESETSAVEREQUEST = DESCRIPTOR.message_types_by_name['DataSourceSetSaveRequest']
_DATASOURCEIDREPLY = DESCRIPTOR.message_types_by_name['DataSourceIDReply']
_DATASOURCESETSAVEREPLY = DESCRIPTOR.message_types_by_name['DataSourceSetSaveReply']
_DATASOURCESTATUSMAP = DESCRIPTOR.message_types_by_name['DataSourceStatusMap']
_DATASOURCESTATUSMAP_DSOURCEENTRY = _DATASOURCESTATUSMAP.nested_types_by_name['DsourceEntry']
_COPYREMOVEDATASOURCEFILEREQUEST = DESCRIPTOR.message_types_by_name['CopyRemoveDataSourceFileRequest']
_COPYREMOVEDATASOURCEFILEREQUEST_MULTIPLEFILES = _COPYREMOVEDATASOURCEFILEREQUEST.nested_types_by_name['MultipleFiles']
_COPYREMOVEDATASOURCEFILEREQUEST_ONEFILE = _COPYREMOVEDATASOURCEFILEREQUEST.nested_types_by_name['OneFile']
_DATASOURCEFILESETSTAT = DESCRIPTOR.message_types_by_name['DataSourceFileSetStat']
_CPRMMVLSREPLY = DESCRIPTOR.message_types_by_name['CpRmMvLsReply']
_CPRMMVLSREPLY_DATASOURCEINFO = _CPRMMVLSREPLY.nested_types_by_name['DataSourceInfo']
_BACKGROUNDPROCESSSTATUS = DESCRIPTOR.message_types_by_name['BackgroundProcessStatus']
_MOVEDATASOURCEFILEREQUEST = DESCRIPTOR.message_types_by_name['MoveDataSourceFileRequest']
_DATASOURCESTATUS = DESCRIPTOR.message_types_by_name['DataSourceStatus']
_DATASOURCEPARAMS = DESCRIPTOR.message_types_by_name['DataSourceParams']
_IMPEDANCEREQUEST = DESCRIPTOR.message_types_by_name['ImpedanceRequest']
_IMPEDANCE = DESCRIPTOR.message_types_by_name['Impedance']
_IMPEDANCE_IMPEDANCEVALUE = _IMPEDANCE.nested_types_by_name['ImpedanceValue']
DataSourceRequest = _reflection.GeneratedProtocolMessageType('DataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEREQUEST,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceRequest)
  })
_sym_db.RegisterMessage(DataSourceRequest)

DataSourceSetSaveRequest = _reflection.GeneratedProtocolMessageType('DataSourceSetSaveRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESETSAVEREQUEST,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceSetSaveRequest)
  })
_sym_db.RegisterMessage(DataSourceSetSaveRequest)

DataSourceIDReply = _reflection.GeneratedProtocolMessageType('DataSourceIDReply', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEIDREPLY,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceIDReply)
  })
_sym_db.RegisterMessage(DataSourceIDReply)

DataSourceSetSaveReply = _reflection.GeneratedProtocolMessageType('DataSourceSetSaveReply', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESETSAVEREPLY,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceSetSaveReply)
  })
_sym_db.RegisterMessage(DataSourceSetSaveReply)

DataSourceStatusMap = _reflection.GeneratedProtocolMessageType('DataSourceStatusMap', (_message.Message,), {

  'DsourceEntry' : _reflection.GeneratedProtocolMessageType('DsourceEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASOURCESTATUSMAP_DSOURCEENTRY,
    '__module__' : 'datasource_pb2'
    # @@protoc_insertion_point(class_scope:allego.DataSourceStatusMap.DsourceEntry)
    })
  ,
  'DESCRIPTOR' : _DATASOURCESTATUSMAP,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceStatusMap)
  })
_sym_db.RegisterMessage(DataSourceStatusMap)
_sym_db.RegisterMessage(DataSourceStatusMap.DsourceEntry)

CopyRemoveDataSourceFileRequest = _reflection.GeneratedProtocolMessageType('CopyRemoveDataSourceFileRequest', (_message.Message,), {

  'MultipleFiles' : _reflection.GeneratedProtocolMessageType('MultipleFiles', (_message.Message,), {
    'DESCRIPTOR' : _COPYREMOVEDATASOURCEFILEREQUEST_MULTIPLEFILES,
    '__module__' : 'datasource_pb2'
    # @@protoc_insertion_point(class_scope:allego.CopyRemoveDataSourceFileRequest.MultipleFiles)
    })
  ,

  'OneFile' : _reflection.GeneratedProtocolMessageType('OneFile', (_message.Message,), {
    'DESCRIPTOR' : _COPYREMOVEDATASOURCEFILEREQUEST_ONEFILE,
    '__module__' : 'datasource_pb2'
    # @@protoc_insertion_point(class_scope:allego.CopyRemoveDataSourceFileRequest.OneFile)
    })
  ,
  'DESCRIPTOR' : _COPYREMOVEDATASOURCEFILEREQUEST,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.CopyRemoveDataSourceFileRequest)
  })
_sym_db.RegisterMessage(CopyRemoveDataSourceFileRequest)
_sym_db.RegisterMessage(CopyRemoveDataSourceFileRequest.MultipleFiles)
_sym_db.RegisterMessage(CopyRemoveDataSourceFileRequest.OneFile)

DataSourceFileSetStat = _reflection.GeneratedProtocolMessageType('DataSourceFileSetStat', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEFILESETSTAT,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceFileSetStat)
  })
_sym_db.RegisterMessage(DataSourceFileSetStat)

CpRmMvLsReply = _reflection.GeneratedProtocolMessageType('CpRmMvLsReply', (_message.Message,), {

  'DataSourceInfo' : _reflection.GeneratedProtocolMessageType('DataSourceInfo', (_message.Message,), {
    'DESCRIPTOR' : _CPRMMVLSREPLY_DATASOURCEINFO,
    '__module__' : 'datasource_pb2'
    # @@protoc_insertion_point(class_scope:allego.CpRmMvLsReply.DataSourceInfo)
    })
  ,
  'DESCRIPTOR' : _CPRMMVLSREPLY,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.CpRmMvLsReply)
  })
_sym_db.RegisterMessage(CpRmMvLsReply)
_sym_db.RegisterMessage(CpRmMvLsReply.DataSourceInfo)

BackgroundProcessStatus = _reflection.GeneratedProtocolMessageType('BackgroundProcessStatus', (_message.Message,), {
  'DESCRIPTOR' : _BACKGROUNDPROCESSSTATUS,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.BackgroundProcessStatus)
  })
_sym_db.RegisterMessage(BackgroundProcessStatus)

MoveDataSourceFileRequest = _reflection.GeneratedProtocolMessageType('MoveDataSourceFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVEDATASOURCEFILEREQUEST,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.MoveDataSourceFileRequest)
  })
_sym_db.RegisterMessage(MoveDataSourceFileRequest)

DataSourceStatus = _reflection.GeneratedProtocolMessageType('DataSourceStatus', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESTATUS,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceStatus)
  })
_sym_db.RegisterMessage(DataSourceStatus)

DataSourceParams = _reflection.GeneratedProtocolMessageType('DataSourceParams', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEPARAMS,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.DataSourceParams)
  })
_sym_db.RegisterMessage(DataSourceParams)

ImpedanceRequest = _reflection.GeneratedProtocolMessageType('ImpedanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMPEDANCEREQUEST,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.ImpedanceRequest)
  })
_sym_db.RegisterMessage(ImpedanceRequest)

Impedance = _reflection.GeneratedProtocolMessageType('Impedance', (_message.Message,), {

  'ImpedanceValue' : _reflection.GeneratedProtocolMessageType('ImpedanceValue', (_message.Message,), {
    'DESCRIPTOR' : _IMPEDANCE_IMPEDANCEVALUE,
    '__module__' : 'datasource_pb2'
    # @@protoc_insertion_point(class_scope:allego.Impedance.ImpedanceValue)
    })
  ,
  'DESCRIPTOR' : _IMPEDANCE,
  '__module__' : 'datasource_pb2'
  # @@protoc_insertion_point(class_scope:allego.Impedance)
  })
_sym_db.RegisterMessage(Impedance)
_sym_db.RegisterMessage(Impedance.ImpedanceValue)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\023internal/radix/grpc'
  _DATASOURCESTATUSMAP_DSOURCEENTRY._options = None
  _DATASOURCESTATUSMAP_DSOURCEENTRY._serialized_options = b'8\001'
  _RADIENSDATASOURCETYPE._serialized_start=2682
  _RADIENSDATASOURCETYPE._serialized_end=2742
  _DATASOURCEREQUEST._serialized_start=75
  _DATASOURCEREQUEST._serialized_end=135
  _DATASOURCESETSAVEREQUEST._serialized_start=138
  _DATASOURCESETSAVEREQUEST._serialized_end=312
  _DATASOURCEIDREPLY._serialized_start=314
  _DATASOURCEIDREPLY._serialized_end=351
  _DATASOURCESETSAVEREPLY._serialized_start=353
  _DATASOURCESETSAVEREPLY._serialized_end=438
  _DATASOURCESTATUSMAP._serialized_start=441
  _DATASOURCESTATUSMAP._serialized_end=615
  _DATASOURCESTATUSMAP_DSOURCEENTRY._serialized_start=543
  _DATASOURCESTATUSMAP_DSOURCEENTRY._serialized_end=615
  _COPYREMOVEDATASOURCEFILEREQUEST._serialized_start=618
  _COPYREMOVEDATASOURCEFILEREQUEST._serialized_end=1035
  _COPYREMOVEDATASOURCEFILEREQUEST_MULTIPLEFILES._serialized_start=825
  _COPYREMOVEDATASOURCEFILEREQUEST_MULTIPLEFILES._serialized_end=941
  _COPYREMOVEDATASOURCEFILEREQUEST_ONEFILE._serialized_start=943
  _COPYREMOVEDATASOURCEFILEREQUEST_ONEFILE._serialized_end=1027
  _DATASOURCEFILESETSTAT._serialized_start=1038
  _DATASOURCEFILESETSTAT._serialized_end=1414
  _CPRMMVLSREPLY._serialized_start=1417
  _CPRMMVLSREPLY._serialized_end=1675
  _CPRMMVLSREPLY_DATASOURCEINFO._serialized_start=1576
  _CPRMMVLSREPLY_DATASOURCEINFO._serialized_end=1675
  _BACKGROUNDPROCESSSTATUS._serialized_start=1677
  _BACKGROUNDPROCESSSTATUS._serialized_end=1798
  _MOVEDATASOURCEFILEREQUEST._serialized_start=1801
  _MOVEDATASOURCEFILEREQUEST._serialized_end=1940
  _DATASOURCESTATUS._serialized_start=1943
  _DATASOURCESTATUS._serialized_end=2302
  _DATASOURCEPARAMS._serialized_start=2305
  _DATASOURCEPARAMS._serialized_end=2496
  _IMPEDANCEREQUEST._serialized_start=2498
  _IMPEDANCEREQUEST._serialized_end=2544
  _IMPEDANCE._serialized_start=2547
  _IMPEDANCE._serialized_end=2680
  _IMPEDANCE_IMPEDANCEVALUE._serialized_start=2614
  _IMPEDANCE_IMPEDANCEVALUE._serialized_end=2680
# @@protoc_insertion_point(module_scope)
